==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Sistemoji</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Sille Në Ballë</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Sille Përpara</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Dërgoje Më Pas</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Dërgoje Pas</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Përzgjidhe Këtë</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Përpunojeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Rregullime të Përgjithshme</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Rregullime Figurash</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Ngjyrë</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Ngjyrë Teksti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Gjerësi</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Number Seed</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Obfuscation Factor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Item Shadow</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Rregullime Objekti</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Mbyll Tjetrin</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Mbylli Krejt</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Mbylli Krejt ata Majtas</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Mbylli Krejt ata Djathtas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Përzgjedhje Mjeti</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>E aktivizuar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>E çaktivizuar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Gj:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikoje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Dukshmëri Anësh dhe Mbushjeje</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Anë dhe Mbushje</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Anë dhe Pa Mbushje</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Pa Anë dhe Pa Mbushje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Madhësi Shkronjash</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Të trasha</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Të pjerrëta</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Të nënvijëzuara</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekte Figurash</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Pa Efekte</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Drop Shadow</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Shkallë të grisë</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Anë</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Përmbyse Ngjyrën</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>E kufizuar</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Kur aktivizohet, e bën kanavacën
të përfshijë figurën sfond.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Gj:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikoje</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Ngjyrë:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Ngjyrë Sfondi Kanavace</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rrotulloje Figurën</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Në kah orar</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Në kah antiorar</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrar</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Vlerat pozitive prodhojnë rrotullim në kah orar, vlerat negative në kah antiorar.
Rrotullimi me shumëfisha jo të 90° mund të sjellë humbje të cilësisë.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rrotulloje</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Ktheje më anë tjetër</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Përshkallëzoje Figurën</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Ruaji Përpjesëtimet</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Gjerësi:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Lartësi:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Përqindje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Ngjitës</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Përzgjidhe</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penë</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numër</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Drejtkëndësh Shenjë</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elips Shenjë</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Penë Shenjë</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Shigjetë</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Shigjetë Dyshe</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vijë</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Turbullim</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Drejtkëndësh</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Tregues Numri</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Ngjitës</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikselizoje</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Tregues Teksti</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Shigjetë Teksti</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Shigjetë Numrash</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Përsëdytje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zmadhoje (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zvogëloje (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Rikthe Zoom-in te parazgjedhja (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.1.orig.tar.gz: kImageAnnotator-0.7.1/translations/kImageAnnotator_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Sistemoji</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Sille Para</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Sille Përpara</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Dërgoje Prapa</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Dërgoje Pas</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Përzgjidhe Këtë</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Përpunojeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Kontrolle</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Rregullime të Përgjithshme</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Rregullime Figurash</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Ngjyrë</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Ngjyrë Teksti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Gjerësi</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Number Seed</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Obfuscation Factor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Item Shadow</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Rregullime Objekti</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Ripërmasojeni</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Patejdukshmëri</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Mbyll Tjetrin</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Mbylli Krejt</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Mbylli Krejt ata Majtas</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Mbylli Krejt ata Djathtas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Përzgjedhje Mjeti</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>E aktivizuar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>E çaktivizuar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Zhbëje</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ribëje</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Qethe</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Ripërmasojeni</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rrotulloje</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Ndryshoni kanavacën</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Prije</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Gj:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikoje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Vertika</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikoje</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Dukshmëri Anësh dhe Mbushjeje</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Anë dhe Mbushje</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Anë dhe Pa Mbushje</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Pa Anë dhe Pa Mbushje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Madhësi Shkronjash</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Të trasha</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Të pjerrëta</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Të nënvijëzuara</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekte Figurash</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Pa Efekte</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Drop Shadow</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Shkallë të grisë</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Anë</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Përmbyse Ngjyrën</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>E kufizuar</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Kur aktivizohet, e bën kanavacën
të përfshijë figurën sfond.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Gj:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikoje</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Ngjyrë:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Ngjyrë Sfondi Kanavace</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rrotulloje Figurën</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Në kah orar</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Në kah antiorar</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrar</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Vlerat pozitive prodhojnë rrotullim në kah orar, vlerat negative në kah antiorar.
Rrotullimi me shumëfisha jo të 90° mund të sjellë humbje të cilësisë.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rrotulloje</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Ktheje më anë tjetër</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Përshkallëzoje Figurën</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Ruaji Përpjesëtimet</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Gjerësi:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Lartësi:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Përqindje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Ngjitës</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Përzgjidhe</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penë</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numër</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Drejtkëndësh Shenjë</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elips Shenjë</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Penë Shenjë</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Shigjetë</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Shigjetë Dyshe</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vijë</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Turbullim</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Drejtkëndësh</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Tregues Numri</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Ngjitës</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikselizoje</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Tregues Teksti</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Shigjetë Teksti</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Shigjetë Numrash</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Përsëdytje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zmadhoje (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zvogëloje (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Rikthe Zoom-in te parazgjedhja (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
